<?php

require_once("Mail/mimeDecode.php");

/**
	Container class for a decoded MIME email
	plus some logic for reading content in the email
*/
class SimpleMailMessage{

	var $mimedecodeparams;
	
	var $headers;
	var $ctype_primary;
	var $cyype_secondary;
	var $disposition;
	var $d_parameters;
	var $body;
	var $parts;
	
	var $ctype;
	
	var $rawcontent;
	var $isdecoded;
	
	function SimpleMailMessage($rawcontent){
		$this->mimedecodeparams=array();
		$this->mimedecodeparams['include_bodies'] = TRUE;
		$this->mimedecodeparams['decode_bodies']  = TRUE;
		$this->mimedecodeparams['decode_headers'] = TRUE;
		
		$this->headers=array();
		$this->parts=array();
		
		$this->rawcontent=$rawcontent;
		$this->isdecoded=false;
	}
	
	function decode(){
		
		$decoder = new Mail_mimeDecode($this->rawcontent);
		$mimedata = $decoder->decode($this->mimedecodeparams);
		
		if(PEAR::isError($mimedata,$msgcode)){
			$this->error=$msgcode;
			return false;
		}
		
		$this->headers=$mimedata->headers;
		$this->ctype_primary=$mimedata->ctype_primary;
		$this->ctype_secondary=$mimedata->ctype_secondary;
		$this->ctype_parameters=$mimedata->ctype_parameters;
		$this->disposition=$mimedata->disposition;
		$this->d_parameters=$mimedata->d_parameters;
		$this->body=$mimedata->body;
		$this->parts=$mimedata->parts;
		
		$this->ctype=$this->ctype_primary."/".$this->ctype_secondary;
		
		$this->isdecoded=true;
		$this->rawcontent="";
		
		//print("SimpleMailMessage::decode: decoded message, subject is ".$this->getSubject()."<br>\n");
		
		return true;
	}
	
	function getPlainTextVersion(){
		if(!$this->isdecoded){if(!$this->decode())return false;}
		
		if($this->ctype=="text/plain"){
			return $this->body;
		}else{			
			$this->error="Unable to find text of email";
			return false;
		}
	}
	
	/**
		Search for the first matching http:// or https:// link in a text email
		following the given string, or find the first link if no string provided
	*/
	function findLinkAfterText($str=NULL){
		if(!$this->isdecoded){if(!$this->decode())return false;}
		
		if($str==NULL){
			$searchin=$this->getPlainTextVersion();
		}else{
			$alltext=$this->getPlainTextVersion();
			$pos=strpos($alltext,$str);
			if($pos===false){
				$this->error="Text '$str' was not found";
				return false;
			}
			$searchin=substr($alltext,$pos);
		}
		if(preg_match("#(https?://[-a-z0-9\\.]+/[^ ]*)#i",$searchin,$matches)){
			return $matches[1];
		}
		
		$this->error="No link found starting at pos $pos (text is '$searchin')";
		return false;
	}
	
	function getSubject(){
		if(!$this->isdecoded){if(!$this->decode())return false;}
		
		if(isset($this->headers['subject'])){
			return $this->headers['subject'];
		}else{
			return NULL;
		}
	}
	
	function getFrom(){
		if(!$this->isdecoded){if(!$this->decode())return false;}
		
		if(isset($this->headers['from'])){
			return $this->headers['from'];
		}else{
			return NULL;
		}
	}			
}

?>